==> bettertrims-4.0.0%2B1.21.1-fabric-sources.jar: com/bawnorton/bettertrims/data/provider/BetterTrimsDimensionTypeTagProvider.java <==
package com.bawnorton.bettertrims.data.provider;
//? if fabric {

import com.bawnorton.bettertrims.data.BetterTrimsDimensionTypeTags;
import net.fabricmc.fabric.api.datagen.v1.FabricDataOutput;
import net.fabricmc.fabric.api.datagen.v1.provider.FabricTagProvider;
import net.minecraft.class_2874;
import net.minecraft.class_6862;
import net.minecraft.class_7134;
import net.minecraft.class_7225;
import net.minecraft.class_7924;
import java.util.concurrent.CompletableFuture;

public class BetterTrimsDimensionTypeTagProvider extends FabricTagProvider<class_2874> {
	public BetterTrimsDimensionTypeTagProvider(FabricDataOutput output, CompletableFuture<class_7225.class_7874> registriesFuture) {
		super(output, class_7924.field_41241, registriesFuture);
	}

	@Override
	protected void method_10514(class_7225.class_7874 wrapperLookup) {
		builder(BetterTrimsDimensionTypeTags.HAS_SUN)
				.method_46835(class_7134.field_37666);
		builder(BetterTrimsDimensionTypeTags.HAS_MOON)
				.method_46835(class_7134.field_37666);
	}

	//? if 1.21.1 {
	private FabricTagBuilder builder(class_6862<class_2874> type) {
		return getOrCreateTagBuilder(type);
	}
	//?}
}
//?} else {

/*import com.bawnorton.bettertrims.BetterTrims;
import com.bawnorton.bettertrims.data.BetterTrimsDimensionTypeTags;
import net.minecraft.core.HolderLookup;
import net.minecraft.core.registries.Registries;
import net.minecraft.data.PackOutput;
import net.minecraft.data.tags.TagsProvider;
import net.minecraft.resources.ResourceKey;
import net.minecraft.tags.TagKey;
import net.minecraft.world.level.dimension.BuiltinDimensionTypes;
import net.minecraft.world.level.dimension.DimensionType;
import org.jetbrains.annotations.NotNull;
import org.jetbrains.annotations.Nullable;

import java.util.concurrent.CompletableFuture;

//? if >=1.21.8 {
import net.minecraft.data.tags.TagAppender;
//?} else {
/^import net.neoforged.neoforge.common.data.ExistingFileHelper;
import org.jetbrains.annotations.Nullable;
^///?}

public class BetterTrimsDimensionTypeTagProvider extends TagsProvider<DimensionType> {
	//? if <1.21.8 {
	/^public BetterTrimsDimensionTypeTagProvider(PackOutput output, CompletableFuture<HolderLookup.Provider> lookupProvider, @Nullable ExistingFileHelper existingFileHelper) {
		super(output, Registries.DIMENSION_TYPE, lookupProvider, BetterTrims.MOD_ID, existingFileHelper);
	}
	^///?} else {
	public BetterTrimsDimensionTypeTagProvider(PackOutput output, CompletableFuture<HolderLookup.Provider> lookupProvider) {
		super(output, Registries.DIMENSION_TYPE, lookupProvider, BetterTrims.MOD_ID);
	}
	//?}

	@Override
	protected void addTags(@NotNull HolderLookup.Provider provider) {
		tag(BetterTrimsDimensionTypeTags.HAS_SUN)
				.add(BuiltinDimensionTypes.OVERWORLD);
		tag(BetterTrimsDimensionTypeTags.HAS_MOON)
				.add(BuiltinDimensionTypes.OVERWORLD);
	}

	//? if >=1.21.8 {
	private TagAppender<ResourceKey<DimensionType>, DimensionType> tag(TagKey<DimensionType> type) {
		return TagAppender.forBuilder(getOrCreateRawBuilder(type));
	}
	//?}
}
*///?}

==> bettertrims-4.0.2%2B1.21.10-fabric-sources.jar: com/bawnorton/bettertrims/data/provider/BetterTrimsDimensionTypeTagProvider.java <==
package com.bawnorton.bettertrims.data.provider;
//? if fabric {

import com.bawnorton.bettertrims.data.BetterTrimsDimensionTypeTags;
import net.fabricmc.fabric.api.datagen.v1.FabricDataOutput;
import net.fabricmc.fabric.api.datagen.v1.provider.FabricTagProvider;
import net.minecraft.class_2874;
import net.minecraft.class_7134;
import net.minecraft.class_7225;
import net.minecraft.class_7924;
import java.util.concurrent.CompletableFuture;

public class BetterTrimsDimensionTypeTagProvider extends FabricTagProvider<class_2874> {
	public BetterTrimsDimensionTypeTagProvider(FabricDataOutput output, CompletableFuture<class_7225.class_7874> registriesFuture) {
		super(output, class_7924.field_41241, registriesFuture);
	}

	@Override
	protected void method_10514(class_7225.class_7874 wrapperLookup) {
		builder(BetterTrimsDimensionTypeTags.HAS_SUN)
				.method_71554(class_7134.field_37666);
		builder(BetterTrimsDimensionTypeTags.HAS_MOON)
				.method_71554(class_7134.field_37666);
	}

	//? if 1.21.1 {
	/*private FabricTagBuilder builder(TagKey<DimensionType> type) {
		return getOrCreateTagBuilder(type);
	}
	*///?}
}
//?} else {

/*import com.bawnorton.bettertrims.BetterTrims;
import com.bawnorton.bettertrims.data.BetterTrimsDimensionTypeTags;
import net.minecraft.core.HolderLookup;
import net.minecraft.core.registries.Registries;
import net.minecraft.data.PackOutput;
import net.minecraft.data.tags.TagsProvider;
import net.minecraft.resources.ResourceKey;
import net.minecraft.tags.TagKey;
import net.minecraft.world.level.dimension.BuiltinDimensionTypes;
import net.minecraft.world.level.dimension.DimensionType;
import org.jetbrains.annotations.NotNull;
import org.jetbrains.annotations.Nullable;

import java.util.concurrent.CompletableFuture;

//? if >=1.21.8 {
import net.minecraft.data.tags.TagAppender;
//?} else {
/^import net.neoforged.neoforge.common.data.ExistingFileHelper;
import org.jetbrains.annotations.Nullable;
^///?}

public class BetterTrimsDimensionTypeTagProvider extends TagsProvider<DimensionType> {
	//? if <1.21.8 {
	/^public BetterTrimsDimensionTypeTagProvider(PackOutput output, CompletableFuture<HolderLookup.Provider> lookupProvider, @Nullable ExistingFileHelper existingFileHelper) {
		super(output, Registries.DIMENSION_TYPE, lookupProvider, BetterTrims.MOD_ID, existingFileHelper);
	}
	^///?} else {
	public BetterTrimsDimensionTypeTagProvider(PackOutput output, CompletableFuture<HolderLookup.Provider> lookupProvider) {
		super(output, Registries.DIMENSION_TYPE, lookupProvider, BetterTrims.MOD_ID);
	}
	//?}

	@Override
	protected void addTags(@NotNull HolderLookup.Provider provider) {
		tag(BetterTrimsDimensionTypeTags.HAS_SUN)
				.add(BuiltinDimensionTypes.OVERWORLD);
		tag(BetterTrimsDimensionTypeTags.HAS_MOON)
				.add(BuiltinDimensionTypes.OVERWORLD);
	}

	//? if >=1.21.8 {
	private TagAppender<ResourceKey<DimensionType>, DimensionType> tag(TagKey<DimensionType> type) {
		return TagAppender.forBuilder(getOrCreateRawBuilder(type));
	}
	//?}
}
*///?}
